%if 0%{?fedora} || 0%{?rhel} == 6
%global with_devel 1
%global with_bundled 0
%global with_debug 0
# needs etcd running
%global with_check 0
%global with_unit_test 1
%else
%global with_devel 0
%global with_bundled 0
%global with_debug 0
%global with_check 0
%global with_unit_test 0
%endif

%if 0%{?with_debug}
%global _dwz_low_mem_die_limit 0
%else
%global debug_package   %{nil}
%endif

%global isgccgoarch 0
%if 0%{?gccgo_arches:1}
%ifarch %{gccgo_arches}
%global isgccgoarch 1
%endif
%endif

%global provider        github
%global provider_tld    com
%global project         coreos
%global repo            go-etcd
# https://github.com/coreos/go-etcd
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path     %{provider_prefix}
%global commit          68b33a3ba02a45d5f98bd7952e3e63e653a38252
%global shortcommit     %(c=%{commit}; echo ${c:0:7})

Name:           golang-%{provider}-%{project}-%{repo}
Version:        2.0.0
Release:        0.5.git%{shortcommit}%{?dist}
Summary:        Go client library for etcd
License:        ASL 2.0
URL:            https://%{provider_prefix}
Source0:        https://%{provider_prefix}/archive/%{commit}/%{repo}-%{shortcommit}.tar.gz
Patch0:         change-default-ports.patch

# e.g. el6 has ppc64 arch without gcc-go, so EA tag is required
ExclusiveArch:  %{?go_arches:%{go_arches}}%{!?go_arches:%{ix86} x86_64 %{arm}}
# If go_compiler is not set to 1, there is no virtual provide. Use golang instead.
BuildRequires:  %{?go_compiler:compiler(go-compiler)}%{!?go_compiler:golang}

%description
%{summary}

%if 0%{?with_devel}
%package devel
Summary:       %{summary}
BuildArch:     noarch

%if 0%{?with_check}
BuildRequires: golang(github.com/ugorji/go/codec)
%endif

Requires:      golang(github.com/ugorji/go/codec)

Provides:      golang(%{import_path}/etcd) = %{version}-%{release}

%description devel
%{summary}

This package contains library source intended for
building other packages which use import path with
%{import_path} prefix.
%endif

%if 0%{?with_unit_test} && 0%{?with_devel}
%package unit-test
Summary:         Unit tests for %{name} package
# If go_compiler is not set to 1, there is no virtual provide. Use golang instead.
BuildRequires:  %{?go_compiler:compiler(go-compiler)}%{!?go_compiler:golang}

%if 0%{?with_check}
#Here comes all BuildRequires: PACKAGE the unit tests
#in %%check section need for running
%endif

# test subpackage tests code from devel subpackage
Requires:        %{name}-devel = %{version}-%{release}

%description unit-test
%{summary}

This package contains unit tests for project
providing packages with %{import_path} prefix.
%endif

%prep
%setup -q -n %{repo}-%{commit}
%patch0 -p1

%build

%install
# source codes for building projects
%if 0%{?with_devel}
install -d -p %{buildroot}/%{gopath}/src/%{import_path}/
echo "%%dir %%{gopath}/src/%%{import_path}/." >> devel.file-list
# find all *.go but no *_test.go files and generate devel.file-list
for file in $(find . -iname "*.go" \! -iname "*_test.go") ; do
    echo "%%dir %%{gopath}/src/%%{import_path}/$(dirname $file)" >> devel.file-list
    echo "%%dir %%{gopath}/src/%%{import_path}/$(dirname $file)" >> devel.file-list
    install -d -p %{buildroot}/%{gopath}/src/%{import_path}/$(dirname $file)
    cp -pav $file %{buildroot}/%{gopath}/src/%{import_path}/$file
    echo "%%{gopath}/src/%%{import_path}/$file" >> devel.file-list
done
%endif

# testing files for this project
%if 0%{?with_unit_test} && 0%{?with_devel}
install -d -p %{buildroot}/%{gopath}/src/%{import_path}/
# find all *_test.go files and generate unit-test.file-list
for file in $(find . -iname "*_test.go"); do
    echo "%%dir %%{gopath}/src/%%{import_path}/$(dirname $file)" >> devel.file-list
    echo "%%dir %%{gopath}/src/%%{import_path}/$(dirname $file)" >> devel.file-list
    install -d -p %{buildroot}/%{gopath}/src/%{import_path}/$(dirname $file)
    cp -pav $file %{buildroot}/%{gopath}/src/%{import_path}/$file
    echo "%%{gopath}/src/%%{import_path}/$file" >> unit-test.file-list
done
%endif

%if 0%{?with_devel}
sort -u -o devel.file-list devel.file-list
%endif

%if 0%{?with_devel}
sort -u -o devel.file-list devel.file-list
%endif

%check
%if 0%{?with_check} && 0%{?with_unit_test} && 0%{?with_devel}
%if %{isgccgoarch}
function gotest { %{gcc_go_test} "$@"; }
%else
%if 0%{?golang_test:1}
function gotest { %{golang_test} "$@"; }
%else
function gotest { go test "$@"; }
%endif
%endif

%if ! 0%{?with_bundled}
export GOPATH=%{buildroot}/%{gopath}:%{gopath}
%else
export GOPATH=%{buildroot}/%{gopath}:$(pwd)/Godeps/_workspace:%{gopath}
%endif

%if ! 0%{?gotest:1}
%global gotest go test
%endif

%gotest %{import_path}/etcd
%endif

#define license tag if not already defined
%{!?_licensedir:%global license %doc}

%if 0%{?with_devel}
%files devel -f devel.file-list
%license LICENSE
%doc README.md
%dir %{gopath}/src/%{provider}.%{provider_tld}/%{project}
%endif

%if 0%{?with_unit_test} && 0%{?with_devel}
%files unit-test -f unit-test.file-list
%license LICENSE
%doc README.md
%endif

%changelog
* Tue Oct 27 2015 jchaloup <jchaloup@redhat.com> - 2.0.0-0.5.git68b33a3
- Bump to upstream 68b33a3ba02a45d5f98bd7952e3e63e653a38252
  related: #1246214

* Sat Sep 12 2015 jchaloup <jchaloup@redhat.com> - 2.0.0-0.4.git4cceaf7
- Update to spec-2.1
  related: #1246214

* Mon Aug 31 2015 jchaloup <jchaloup@redhat.com> - 2.0.0-0.3.git4cceaf7
- Bump to upstream 4cceaf7283b76f27c4a732b20730dcdb61053bf5
  resolves: #1246214

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.0-0.2.git0424b5f
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Mon Apr 20 2015 jchaloup <jchaloup@redhat.com> - 2.0.0-0.1.git0424b5f
- Bump to upstream 0424b5f86ef0ca57a5309c599f74bbb3e97ecd9d
  related: #1141807

* Fri Apr 10 2015 Eric Paris <eparis@redhat.com>
- Bump to version supporting etcd 2.0

* Tue Apr 7 2015 Eric Paris <eparis@redhat.com>
- include etcd dep

* Tue Mar 31 2015 jchaloup <jchaloup@redhat.com> - 0.4.6-0.2.rc1.git2af7a95
- Bump to upstream 2af7a9525b09fb715b215a1fb852dd4814ef52b5
  related: #1141807

* Wed Feb 18 2015 jchaloup <jchaloup@redhat.com> - 0.4.6-0.1.rc1.git6aa2da5
- Bump to upstream 6aa2da5a7a905609c93036b9307185a04a5a84a5
  related: #1141807

* Wed Jan 28 2015 jchaloup <jchaloup@redhat.com> - 0.2.0-0.5.rc1.gitb7c233e
- Bump to upstream b7c233e2ef9be1016c63f66145161b317165ad7e
  related: #1141807

* Thu Oct 23 2014 jchaloup <jchaloup@redhat.com> - 0.2.0-0.4.rc1.git6fe04d5
- Choose the correct architecture
  related: #1141807

* Thu Oct 23 2014 jchaloup <jchaloup@redhat.com> - 0.2.0-0.3.rc1.git6fe04d5
- Bump to upstream 6fe04d580dfb71c9e34cbce2f4df9eefd1e1241e
  resolves: #1141807

* Mon Sep 15 2014 Lokesh Mandvekar <lsm5@fedoraproject.org> - 0.2.0-0.2.rc1.git23142f6
 - do not redefine gopath
 - do not own dirs owned by golang
 - correct version number, rc tag goes in release
 - noarch

* Sat Sep 06 2014 Eric Paris <eparis@redhat.com - 0.2.rc1-0.1.git23142f67.2
- Bump to upstream 23142f6773a676cc2cae8dd0cb90b2ea761c853f

* Wed Aug 20 2014 Adam Miller <maxamillion@fedoraproject.org> - 0.2.0-0.1-rc1
- Initial fedora package

